"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.build = void 0;
var path = require("path");
var fs = require("fs");
var webpack = require("webpack");
var getConfig_1 = require("./getConfig");
var webpackConfig_1 = require("./webpackConfig");
var logger_1 = require("./utils/logger");
function build(options) {
    process.env.NODE_ENV = 'production';
    logger_1.Logger.start('Starting bundler in production mode');
    var root = options.root, configFile = options.config;
    var configFilePath = path.resolve(root, configFile);
    if (!fs.existsSync(configFilePath)) {
        logger_1.Logger.error("Config file not found: ".concat(configFilePath));
        process.exit(1);
    }
    var userConfig = (0, getConfig_1.getUserConfig)(configFilePath);
    var config = userConfig.map(function (config) { return (0, webpackConfig_1.webpackConfig)({
        root: root,
        config: config,
    }); });
    webpack(config, function (error, stats) {
        if (error) {
            logger_1.Logger.error('Failed to build', error);
            process.exit(1);
        }
        if (stats.hasErrors()) {
            logger_1.Logger.error('Failed to build', stats.toString('errors-only'));
            process.exit(1);
        }
        logger_1.Logger.success('Build completed');
    });
}
exports.build = build;
