"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.dev = void 0;
var fs = require("fs");
var path = require("path");
var webpack = require("webpack");
var WebpackDevServer = require("webpack-dev-server");
var getConfig_1 = require("./getConfig");
var webpackConfig_1 = require("./webpackConfig");
var logger_1 = require("./utils/logger");
function dev(options) {
    process.env.NODE_ENV = 'development';
    logger_1.Logger.start('Starting bundler in development mode');
    var root = options.root, configFile = options.config;
    var configFilePath = path.resolve(root, configFile);
    if (!fs.existsSync(configFilePath)) {
        logger_1.Logger.error("Config file not found: ".concat(configFilePath));
        process.exit(1);
    }
    var userConfig = (0, getConfig_1.getUserConfig)(configFilePath);
    var config = userConfig.map(function (config) { return (0, webpackConfig_1.webpackConfig)({
        root: root,
        config: config,
    }); });
    var _a = userConfig[0], _b = _a.devServer, devServer = _b === void 0 ? {} : _b, publicPath = _a.publicPath;
    var serverConfig = __assign({ port: 8080, compress: true, headers: {
            'access-control-allow-origin': '*',
        }, historyApiFallback: true, host: '0.0.0.0', client: {
            overlay: true,
            progress: false,
        }, static: {
            directory: path.resolve(root, 'public'),
            publicPath: publicPath,
        }, hot: true }, devServer);
    WebpackDevServer.getFreePort(serverConfig.port, serverConfig.host)
        .then(function (port) {
        var complier = webpack(config);
        var server = new WebpackDevServer(serverConfig, complier);
        server.start().then(function () {
            logger_1.Logger.success('Development server started');
        }).catch(function (error) {
            logger_1.Logger.error('Failed to start the development server', error);
        });
    })
        .catch(function (error) {
        logger_1.Logger.error(error);
    });
}
exports.dev = dev;
